@@ -134,9 +134,9 @@ For a full list of contributors, please check <a href="https://github.com/indili
 #define INDIV 1.7
 
 /* INDI Library version */
-#define INDI_VERSION_MAJOR   1
-#define INDI_VERSION_MINOR   9
-#define INDI_VERSION_RELEASE 7
+#define INDI_VERSION_MAJOR   2
+#define INDI_VERSION_MINOR   0
+#define INDI_VERSION_RELEASE 0
 
 /*******************************************************************************
  * Manifest constants
@@ -513,21 +513,7 @@ extern "C" {
 
 // Advertize support for shared blob on this platform
 #define INDI_SHARED_BLOB_SUPPORT
-
-/** \brief Allocate a buffer suitable for fast exchange over local links. Warning : the buffer will be sealed (readonly) once exchanged.
-    \param size_t size of the memory area to allocate
- */
-extern void * IDSharedBlobAlloc(size_t size);
-
-/** \brief Adjust the size of a buffer obtained using IDSharedBlobAlloc.
-    \param size_t size of the memory area to allocate
- */
-extern void * IDSharedBlobRealloc(void * ptr, size_t size);
-
-/** \brief Free a buffer allocated using IDSharedBlobAlloc. Fall back to free for buffer that are not shared blob
- * Must be used for IBLOB.data
- */
-extern void IDSharedBlobFree(void * ptr);
+#include "sharedblob.h"
 
 #ifdef __cplusplus
 }
