@@ -66,26 +66,37 @@ class Correlator : public SensorInterface
          * \struct Baseline
          * \brief the baseline (position of the telescopes) of this correlator.
          */
-        typedef struct {
-            double x;
-            double y;
-            double z;
+        typedef union
+        {
+            struct
+            {
+                double x;
+                double y;
+                double z;
+            };
+            double values[3];
         } Baseline;
 
         /**
          * \enum UVCoordinate
          * \brief The coordinates of the current projection into the UV plane.
          */
-        typedef struct {
-            double u;
-            double v;
+        typedef union
+        {
+            struct
+            {
+                double u;
+                double v;
+            };
+            double values[2];
         } UVCoordinate;
 
         /**
          * \enum Correlation
          * \brief Struct containing the correlation, coordinate and baseline informations.
          */
-        typedef struct {
+        typedef struct
+        {
             Baseline baseline;
             UVCoordinate coordinate;
             double coefficient;
@@ -93,7 +104,7 @@ class Correlator : public SensorInterface
 
         enum
         {
-            CORRELATOR_MAX_CAPABILITY                  = SENSOR_MAX_CAPABILITY<<0,  /*!< Can the Sensor Integration be aborted?  */
+            CORRELATOR_MAX_CAPABILITY                  = SENSOR_MAX_CAPABILITY << 0, /*!< Can the Sensor Integration be aborted?  */
         } CorrelatorCapability;
 
         Correlator();
@@ -105,7 +116,8 @@ class Correlator : public SensorInterface
         bool ISNewNumber(const char *dev, const char *name, double values[], char *names[], int n) override;
         bool ISNewSwitch(const char *dev, const char *name, ISState *states, char *names[], int n) override;
         bool ISNewText(const char *dev, const char *name, char *texts[], char *names[], int n) override;
-        bool ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[], char *names[], int n) override;
+        bool ISNewBLOB(const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[],
+                       char *names[], int n) override;
         bool ISSnoopDevice(XMLEle *root) override;
 
         virtual bool StartIntegration(double duration) override;
@@ -114,13 +126,23 @@ class Correlator : public SensorInterface
          * @brief getCorrelationDegree Get current correlation degree.
          * @return the correlation coefficient.
          */
-        virtual inline double getCorrelationDegree() { return 0.0; }
+        virtual inline double getCorrelationDegree()
+        {
+            return 0.0;
+        }
 
         /**
          * @brief getCorrelation Get current correlation degree plus UV and baseline information.
          * @return the correlation and UV coordinates.
          */
-        inline Correlation getCorrelation() { Correlation ret; ret.coordinate = getUVCoordinates(); ret.baseline = baseline; ret.coefficient = getCorrelationDegree(); return ret; }
+        inline Correlation getCorrelation()
+        {
+            Correlation ret;
+            ret.coordinate = getUVCoordinates();
+            ret.baseline = baseline;
+            ret.coefficient = getCorrelationDegree();
+            return ret;
+        }
 
         /**
          * @brief setBaseline Set the baseline size in meters.
@@ -159,11 +181,47 @@ class Correlator : public SensorInterface
         }
 
         /**
-         * @brief getUVCoordinates Get current UV projected coordinates.
+         * @brief getUVCoordinates Get current UV projected coordinates with reference to the current sidereal time.
          * @return the UV coordinates.
          */
         UVCoordinate getUVCoordinates();
 
+        /**
+         * @brief getUVCoordinates Get current UV projected coordinates with reference to the given sidereal time.
+         * \param lst the local sidereal time
+         * @return the UV coordinates.
+         */
+        UVCoordinate getUVCoordinates(double lst);
+
+        /**
+         * @brief getUVCoordinates Get current UV projected coordinates with reference to zenith/azimuth baseline.
+         * \param alt altitude of the target
+         * \param az azimuth of the target
+         * @return the UV coordinates.
+         */
+        UVCoordinate getUVCoordinates(double alt, double az);
+
+        /**
+         * @brief getDelay Get current baseline delay with reference to the current sidereal time.
+         * @return the delay in meters.
+         */
+        double getDelay();
+
+        /**
+         * @brief getUVCoordinates Get current baseline delay with reference to the given sidereal time.
+         * \param lst the local sidereal time
+         * @return the delay in meters.
+         */
+        double getDelay(double lst);
+
+        /**
+         * @brief getUVCoordinates Get current baseline delay with reference to zenith/azimuth baseline.
+         * \param alt altitude of the target
+         * \param az azimuth of the target
+         * @return the delay in meters.
+         */
+        double getDelay(double alt, double az);
+
         /**
          * @brief setBandwidth Get the bandwidth of the correlator.
          * @return the instrumentation bandwidth in Hz.
@@ -190,7 +248,7 @@ class Correlator : public SensorInterface
         }
 
         /**
-         * @brief SetCorrelatorCapability Set the Correlator capabilities. Al fields must be initilized.
+         * @brief SetCorrelatorCapability Set the Correlator capabilities. Al fields must be initialized.
          * @param cap pointer to CorrelatorCapability struct.
          */
         void SetCorrelatorCapability(uint32_t cap);
@@ -205,7 +263,8 @@ class Correlator : public SensorInterface
          * @param sendToClient If true (default), the element limits are updated and is sent to the
          * client. If false, the element limits are updated without getting sent to the client.
          */
-        void setMinMaxStep(const char *property, const char *element, double min, double max, double step, bool sendToClient);
+        virtual void setMinMaxStep(const char *property, const char *element, double min, double max, double step,
+                                   bool sendToClient) override;
 
         typedef enum
         {
@@ -217,7 +276,7 @@ class Correlator : public SensorInterface
         } CORRELATOR_INFO_INDEX;
         INumberVectorProperty CorrelatorSettingsNP;
 
-      private:
+    private:
         Baseline baseline;
         double wavelength;
         double bandwidth;
